@@ -65,7 +65,7 @@ class RedisCache:
                 redis_connection.hset(redis_key, _hash_key, str(_hash_value))
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->put_value_in_hash_set()->>")
-                # raise e
+                raise RGRedisException("RedisCache->put_value_in_hash_set()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=put_value_in_hash_set")
 
@@ -77,7 +77,7 @@ class RedisCache:
                 return redis_connection.hget(redis_key, _key)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->get_value_from_hash_set()->>")
-                # raise e
+                raise RGRedisException("RedisCache->get_value_from_hash_set()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=get_value_from_hash_set")
 
@@ -89,7 +89,7 @@ class RedisCache:
                 return redis_connection.hgetall(_redis_key)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->get_all_values_from_hash_set()->>")
-                # raise e
+                raise RGRedisException("RedisCache->get_all_values_from_hash_set()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=get_all_values_from_hash_set")
 
@@ -101,7 +101,7 @@ class RedisCache:
                 return redis_connection.hdel(_redis_key, _hash_key)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->remove_value_from_hash_set()->>")
-                # raise e
+                raise RGRedisException("RedisCache->remove_value_from_hash_set()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=remove_value_from_hash_set")
 
@@ -113,7 +113,7 @@ class RedisCache:
                 return redis_connection.delete(_redis_key)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->delete_key_from_cache()->>")
-                # raise e
+                raise RGRedisException("RedisCache->delete_key_from_cache()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=delete_key_from_cache")
 
@@ -125,7 +125,7 @@ class RedisCache:
                 return redis_connection.set(_redis_key, _value)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->put_string_value()->>")
-                # raise e
+                raise RGRedisException("RedisCache->put_string_value()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=put_string_value")
 
@@ -137,7 +137,7 @@ class RedisCache:
                 return redis_connection.get(_redis_key)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->get_string_value()->>")
-                # raise e
+                raise RGRedisException("RedisCache->get_string_value()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=get_string_value")
 
@@ -149,6 +149,6 @@ class RedisCache:
                 return redis_connection.incr(_redis_key)
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->get_string_value()->>")
-                # raise e
+                raise RGRedisException("RedisCache->incr_value()->>" + rg_logger.get_exception_msg())
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=incr_value")
